@@ -10,6 +10,10 @@ from .data.data import Data
 from .functions import (_DEPRECATION_ERROR_KWARGS,
                         _DEPRECATION_ERROR_METHOD)
 
+from .decorators import (_inplace_enabled,
+                         _inplace_enabled_define_and_cleanup,
+                         _deprecation_error_i_kwarg)
+
 
 _collapse_cell_methods = {
     'max'            : 'maximum',
@@ -229,7 +233,7 @@ class CellMethod(cfdm.CellMethod):
     >>> c
     >>> c
     <CF CellMethod: time: minimum>
-    >>> print c.within
+    >>> print(c.within)
     None
     >>> c.within = 'years'
     >>> c
@@ -258,7 +262,7 @@ class CellMethod(cfdm.CellMethod):
     >>> c
     >>> c
     <CF CellMethod: time: minimum>
-    >>> print c.where
+    >>> print(c.where)
     None
     >>> c.where = 'land'
     >>> c
@@ -287,7 +291,7 @@ class CellMethod(cfdm.CellMethod):
     >>> c
     >>> c
     <CF CellMethod: time: minimum>
-    >>> print c.over
+    >>> print(c.over)
     None
     >>> c.over = 'years'
     >>> c
@@ -446,28 +450,23 @@ class CellMethod(cfdm.CellMethod):
         self.del_axes(default=AttributeError())
 
 
+    @_deprecation_error_i_kwarg
+    @_inplace_enabled
     def expand_intervals(self, inplace=False, i=False):
         '''TODO
         
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'expand_intervals', i=True) # pragma: no cover
-
-        if inplace:
-            c = self
-        else:
-            c = self.copy()
-
+        c = _inplace_enabled_define_and_cleanup(self)
         n_axes = len(c.get_axes(()))
         intervals = c.get_qualifier('interval', ())
         if n_axes > 1 and len(intervals) == 1:
             c.set_qualifier('interval', intervals * n_axes)
 
-        if inplace:
-            c = None
         return c
 
-    
+
+    @_deprecation_error_i_kwarg
+    @_inplace_enabled
     def change_axes(self, axis_map, inplace=False, i=False):
         '''TODO
 
@@ -478,21 +477,13 @@ class CellMethod(cfdm.CellMethod):
         inplace: `bool`
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'change_axes', i=True) # pragma: no cover
-
-        if inplace:
-            c = self
-        else:
-            c = self.copy()
+        c = _inplace_enabled_define_and_cleanup(self)
 
         if not axis_map:
             return c
 
         c.set_axes([axis_map.get(axis, axis) for axis in self.get_axes(())])
 
-        if inplace:
-            c = None
         return c
 
 
@@ -601,12 +592,15 @@ class CellMethod(cfdm.CellMethod):
     # ----------------------------------------------------------------    
     # Deprecated attributes and methods
     # ----------------------------------------------------------------    
-    def write(self, axis_map={}):
+    def write(self, axis_map=None):
         '''Return a string of the cell method.
 
     Deprecated at version 3.0.0. Use 'str(cell_method)' instead.
 
         '''
+        # Unsafe to set mutable '{}' as default in the func signature.
+        if axis_map is None:  # distinguish from falsy '{}'
+            axis_map = {}
         _DEPRECATED_ERROR_METHOD(
             self, 'write', "Use 'str(cell_method)' instead.") # Pragma: no cover
 
