@@ -14,6 +14,11 @@ from .functions import (_DEPRECATION_ERROR_METHOD,
                         _DEPRECATION_ERROR_ATTRIBUTE,
                         )
 
+from .decorators import (_inplace_enabled,
+                         _inplace_enabled_define_and_cleanup,
+                         _deprecation_error_i_kwarg)
+
+
 _units = {}
 
 
@@ -270,7 +275,7 @@ class CoordinateReference(cfdm.CoordinateReference):
     
     >>> cf.CoordinateReference.default_value('ptop')
     0.0
-    >>> print cf.CoordinateReference.default_value('north_pole_grid_latitude')
+    >>> print(cf.CoordinateReference.default_value('north_pole_grid_latitude'))
     0.0
 
         '''
@@ -488,11 +493,11 @@ class CoordinateReference(cfdm.CoordinateReference):
 
         x = self.coordinate_conversion.get_parameter('grid_mapping_name', None)
         if x is not None:
-            self_identities.append(x)
+            self_identities.insert(0, x)
         
         x = self.coordinate_conversion.get_parameter('standard_name', None)
         if x is not None:
-            self_identities.append(x)
+            self_identities.insert(0, x)
  
         ok = False
         for value0 in identities:          
@@ -516,6 +521,8 @@ class CoordinateReference(cfdm.CoordinateReference):
         return self.match_by_identity(*identities)
 
 
+    @_deprecation_error_i_kwarg
+    @_inplace_enabled
     def change_identifiers(self, identity_map, coordinate=True,
                            ancillary=True, strict=False,
                            inplace=False, i=False):
@@ -554,14 +561,7 @@ class CoordinateReference(cfdm.CoordinateReference):
     {'dim1', 'aux0'}
 
         '''
-     
-        if i:
-            _DEPRECATION_ERROR_KWRAGS(self, 'change_identifiers', i=True) # pragma: no cover
-
-        if inplace:
-            r = self
-        else:
-            r = self.copy()
+        r = _inplace_enabled_define_and_cleanup(self)
 
         if not identity_map and not strict:
             if inplace:
@@ -588,9 +588,7 @@ class CoordinateReference(cfdm.CoordinateReference):
         #--- End: if
 
         r.del_coordinate(None, None)
-        
-        if inplace:
-            r = None            
+
         return r
 
 
