@@ -1,7 +1,9 @@
 from os       import close
 from operator import mul
 
-import numpy
+from numpy import empty  as numpy_empty
+
+from numpy.ma import masked_all as numpy_ma_masked_all
 
 from ..functions import parse_indices, get_subspace
 
@@ -15,10 +17,8 @@ class RaggedContiguousSubarray(abstract.CompressedSubarray):
 
     '''
     def __getitem__(self, indices):
-        '''
+        '''x.__getitem__(indices) <==> x[indices]
 
-    x.__getitem__(indices) <==> x[indices]
-    
     Returns a numpy array.
 
         '''
@@ -27,7 +27,7 @@ class RaggedContiguousSubarray(abstract.CompressedSubarray):
         
         # Initialize the full, uncompressed output array with missing
         # data everywhere
-        uarray = numpy.ma.masked_all(self.shape, dtype=array.dtype)
+        uarray = numpy_ma_masked_all(self.shape, dtype=array.dtype)
 
         r_indices = [slice(None)] * array.ndim
         p_indices = [slice(None)] * uarray.ndim        
@@ -37,6 +37,7 @@ class RaggedContiguousSubarray(abstract.CompressedSubarray):
         instance_index = compression['instance_index']
         element_axis   = compression['c_element_axis']
         sample_indices = compression['c_element_indices']
+
         p_indices[instance_axis] = instance_index
         p_indices[element_axis]  = slice(0, sample_indices.stop - sample_indices.start)
         
@@ -64,11 +65,4 @@ class RaggedContiguousSubarray(abstract.CompressedSubarray):
             return get_subspace(uarray, indices)
 
 
-    def __repr__(self):
-        '''x.__repr__() <==> repr(x)
-
-        '''
-        return "<CF %s: %s>" % (self.__class__.__name__, str(self.array))
-
-
 #--- End: class
