@@ -17,6 +17,8 @@ from .functions import (_DEPRECATION_ERROR_KWARGS,
                         _DEPRECATION_ERROR_ATTRIBUTE,
                         )
 
+from .decorators import _deprecation_error_i_kwarg
+
 
 class DimensionCoordinate(abstract.Coordinate,
                           mixin.PropertiesDataBounds,                          
@@ -470,7 +472,7 @@ class DimensionCoordinate(abstract.Coordinate,
         flt: `float`, optional
             When creating cells with sizes specified by the *cellsize*
             parameter, define the fraction of the each cell which is
-            less its coordinate value. By default *flt* is 05, so that
+            less its coordinate value. By default *flt* is 0.5, so that
             each cell has its coordinate at it's centre. Ignored if
             *cellsize* is not set.
     
@@ -651,12 +653,10 @@ class DimensionCoordinate(abstract.Coordinate,
         return bounds            
 
 
+    @_deprecation_error_i_kwarg
     def flip(self, axes=None, inplace=False, i=False):
         '''TODO
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'flip', i=True) # pragma: no cover
-
         d = super().flip(axes=axes, inplace=inplace)
         if inplace:
             d = self
@@ -825,20 +825,20 @@ class DimensionCoordinate(abstract.Coordinate,
 
         '''
         if not self.Units.islongitude:
-            if verbose: print (0)
+            if verbose: print(0)
             if self.get_property('standard_name', None) not in ('longitude', 'grid_longitude'):
-                if verbose: print (1)
+                if verbose: print(1)
                 return False
         #--- End: if
         
         bounds = self.get_bounds(None)
         if bounds is None:
-            if verbose: print (2)
+            if verbose: print(2)
             return False
 
         bounds_data = bounds.get_data(None)
         if bounds_data is None:
-            if verbose: print (3)
+            if verbose: print(3)
             return False
 
         bounds = bounds_data.array
@@ -848,7 +848,7 @@ class DimensionCoordinate(abstract.Coordinate,
         period.Units = bounds_data.Units
 
         if abs(bounds[-1, -1] - bounds[0, 0]) != period.array:
-            if verbose: print (4)
+            if verbose: print(4)
             return False
 
         self.period(period)
@@ -856,12 +856,10 @@ class DimensionCoordinate(abstract.Coordinate,
         return True
     
 
+    @_deprecation_error_i_kwarg
     def roll(self, axis, shift, inplace=False, i=False):
         '''TODO
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'roll', i=True) # pragma: no cover
-
         if self.size <= 1:
             if inplace:
                 return
