@@ -214,6 +214,7 @@ class FieldList(list):
         '''
         return not self.equals(other)
 
+    
     # ???
     __len__     = list.__len__
     __setitem__ = list.__setitem__    
@@ -224,8 +225,7 @@ class FieldList(list):
     reverse     = list.reverse
     sort        = list.sort
 
-
-
+    
     # ----------------------------------------------------------------
     # Methods
     # ----------------------------------------------------------------
@@ -279,7 +279,7 @@ class FieldList(list):
     Each field in the field list is compared with the field's
     `~cf.Field.equals` method, as opposed to the ``==`` operator.
     
-    It is an error if there is no such field.
+    An exception is raised if there is no such field.
     
     .. seealso:: `list.index`
     
@@ -468,7 +468,7 @@ class FieldList(list):
         '''Whether two field lists are the same.
 
     Equality requires the two field lists to have the same length and
-    for the the field construct elements to be equal pair-wise, using
+    for the field construct elements to be equal pair-wise, using
     their `~cf.Field.equals` methods.
     
     Any type of object may be tested but, in general, equality is only
@@ -690,13 +690,167 @@ class FieldList(list):
         return True	    
 
 
-    def select_by_construct(self, *mode, **constructs):
-        '''TODO
-
-        '''    
-        return type(self)(f for f in self if f.match_by_construct(*mode, **constructs))
+    def select_by_construct(self, *identities, OR=False, **conditions):
+        '''Select field constructs by metadata constructs.
 
+    To find the inverse of the selection, use a list comprehension
+    with the `~cf.Field.match_by_construct` method of the field
+    constucts. For example, to select all field constructs that do
+    *not* have a "latitude" metadata construct:
+            
+       >>> gl = cf.FieldList(f for f in fl
+       ...                   if not f.match_by_constructs('latitude'))
     
+    .. note:: The API changed at version 3.1.0
+
+    .. versionadded:: 3.0.0
+    
+    .. seealso: `select`, `__call__`, `select_by_units`,
+                `select_by_naxes`, `select_by_rank`,
+                `select_by_property`, `cf.Field.match_by_identity`,
+                `cf.Field.subspace`
+    
+    :Parameters:
+    
+        identities: optional
+            Identify the metadata constructs that have any of the
+            given identities or construct keys.
+
+            A construct identity is specified by a string
+            (e.g. ``'latitude'``, ``'long_name=time'``,
+            ``'ncvar%lat'``, etc.); or a compiled regular expression
+            (e.g. ``re.compile('^atmosphere')``) that selects the
+            relevant constructs whose identities match via
+            `re.search`.
+    
+            Each construct has a number of identities, and is selected
+            if any of them match any of those provided. A construct's
+            identities are those returned by its `!identities`
+            method. In the following example, the construct ``x`` has
+            six identities:
+    
+               >>> x.identities()
+               ['time',
+                'long_name=Time',
+                'foo=bar',
+                'standard_name=time',
+                'ncvar%t',
+                'T']
+    
+            A construct key may optionally have the ``'key%'``
+            prefix. For example ``'dimensioncoordinate2'`` and
+            ``'key%dimensioncoordinate2'`` are both acceptable keys.
+    
+            Note that in the output of a `print` call or `!dump`
+            method, a construct is always described by one of its
+            identities, and so this description may always be used as
+            an *identity* argument.
+    
+            If a cell method construct identity is given (such as
+            ``'method:mean'``) then it will only be compared with the
+            most recently applied cell method operation.
+
+            Alternatively, one or more cell method constucts may be
+            identified in a single string with a CF-netCDF cell
+            methods-like syntax for describing both the collapse
+            dimensions, the collapse method, and any cell method
+            construct qualifiers. If N cell methods are described in
+            this way then they will collectively identify the N most
+            recently applied cell method operations. For example,
+            ``'T: maximum within years T: mean over years'`` will be
+            compared with the most two most recently applied cell
+            method operations.
+    
+            *Parameter example:*
+              ``'measure:area'``
+    
+            *Parameter example:*
+              ``'latitude'``
+    
+            *Parameter example:*
+              ``'long_name=Longitude'``
+    
+            *Parameter example:*
+              ``'domainancillary2', 'ncvar%areacello'``
+
+        conditions: optional
+            Identify the metadata constructs that have any of the
+            given identities or construct keys, and whose data satisfy
+            conditions.
+
+            A construct identity or construct key (as defined by the
+            *identities* parameter) is given as a keyword name and a
+            condition on its data is given as the keyword value.
+
+            The condition is satisfied if any of its data values
+            equals the value provided.
+
+            *Parameter example:*
+              ``longitude=180.0``
+    
+            *Parameter example:*
+              ``time=cf.dt('1959-12-16')``
+    
+            *Parameter example:*
+              ``latitude=cf.ge(0)``
+    
+            *Parameter example:*
+              ``latitude=cf.ge(0), air_pressure=500``
+           
+            *Parameter example:*
+              ``**{'latitude': cf.ge(0), 'long_name=soil_level': 4}``
+           
+        OR: `bool`, optional
+            If True then return `True` if at least one metadata
+            construct matches at least one of the criteria given by
+            the *identities* or *conditions* arguments. By default
+            `True` is only returned if the field constructs matches
+            each of the given criteria.
+
+        mode: deprecated at version 3.1.0
+            Use the *OR* parameter instead.
+    
+        constructs: deprecated at version 3.1.0
+        
+    :Returns:
+    
+        `bool`
+            The matching field constructs.
+    
+    **Examples:**
+    
+        TODO
+
+        '''        
+#        if constructs:
+#            for key, value in constructs.items():
+#                if value is None:
+#                    message = "Since its value is None, use {!r} as a positional argument instead".format(value)
+#                else:                    
+#                    message = "Evaluating criteria on data values is not longer possible with this method."
+#
+#                _DEPRECATION_ERROR_KWARGS(self, 'select_by_construct',
+#                                          kwargs={key: value},
+#                                          message=message,
+#                                          version='3.1.0') # pragma: no cover
+#        #--- End: if
+
+        if identities:
+            if identities[0] == 'or':
+                _DEPRECATION_ERROR_ARG(self, 'select_by_construct',
+                                       'or', message="Use 'OR=True' instead.",
+                                       version='3.1.0') # pragma: no cover
+                
+            if identities[0] == 'and':
+                _DEPRECATION_ERROR_ARG(self, 'select_by_construct',
+                                       'and', message="Use 'OR=False' instead.",
+                                       version='3.1.0') # pragma: no cover
+        #--- End: if
+
+        return type(self)(f for f in self
+                          if f.match_by_construct(*identities, OR=OR, **conditions))
+
+
     def select_by_identity(self, *identities):
         '''Select field constructs by identity.
 
@@ -805,7 +959,44 @@ class FieldList(list):
 
     
     def select_by_rank(self, *ranks):
-        '''TODO'''
+        '''Select field constructs by the number of domain axis constructs.    
+
+    .. versionadded:: 3.0.0
+    
+    .. seealso: `select`, `__call__`, `select_by_units`,
+                `select_by_naxes`, `select_by_construct`,
+                `select_by_property`, `cf.Field.match_by_identity`
+ 
+    :Parameters:
+    
+        ranks: optional
+            Define conditions on the number of domain axis constructs.
+    
+            A condition is one of:
+    
+              * `int`
+              * a `Query` object
+    
+            The condition is satisfied if the number of domain axis
+            constructs equals the condition value.
+    
+            *Parameter example:*
+              To see if the field construct has 4 domain axis
+              constructs: ``4``
+    
+            *Parameter example:*
+              To see if the field construct has at least 3 domain axis
+              constructs: ``cf.ge(3)``
+    
+    :Returns:
+    
+        `bool`
+            The matching field constructs.
+    
+    **Examples:**
+    
+        TODO
+        '''
         
         return type(self)(f for f in self if f.match_by_rank(*ranks))
 
@@ -1076,7 +1267,7 @@ class FieldList(list):
        >>> gl = cf.FieldList(f for f in fl
        ...                   if not f.match_by_identity('air_temperature'))
 
-    .. seealso:: `select_field`
+    .. seealso:: `select_by_identity`, `select_field`
 
         '''
         if kwargs:
@@ -1131,11 +1322,13 @@ class FieldList(list):
                    ignore_data_type=False, ignore_fill_value=False,
                    ignore_properties=(), ignore_compression=False,
                    ignore_type=False, traceback=False):
-        '''Deprecated at version 3.0.0. Use method 'equals' instead.
-        
+        '''Deprecated at version 3.0.0. Use method 'equals' with
+    unordered=True instead.
+
         '''
-        _DEPRECATION_ERROR_METHOD(self, 'set_equals',
-                                  "Use method 'equals' instead.") # pragma: no cover
+        _DEPRECATION_ERROR_METHOD(
+            self, 'set_equals',
+            "Use method 'equals' with unordered=True instead.") # pragma: no cover
 
 
     def select1(self, *args, **kwargs):
