@@ -261,14 +261,14 @@ def CHUNKSIZE(*args):
     '''
     old = CONSTANTS['CHUNKSIZE']
     if args:
-        upper_chunksize = (FM_THRESHOLD() / ((mpi_size *
-                                              _WORKSPACE_FACTOR_1()) +
-                                             _WORKSPACE_FACTOR_2()))
+        upper_chunksize = ((FREE_MEMORY_FACTOR() * MIN_TOTAL_MEMORY())
+                           / ((mpi_size * _WORKSPACE_FACTOR_1()) +
+                              _WORKSPACE_FACTOR_2()))
         if args[0] is None:
             CONSTANTS['CHUNKSIZE'] = upper_chunksize
         else:
             chunksize = float(args[0])
-            if chunksize > upper_chunksize:
+            if chunksize > upper_chunksize and mpi_size > 1:
                 raise ValueError(
                     'Specified chunk size is too large for given free memory factor')
             elif chunksize <= 0:
@@ -343,6 +343,11 @@ def SET_PERFORMANCE(chunksize=None, free_memory_factor=None):
 
     return old
 
+def MIN_TOTAL_MEMORY():
+    '''The minumum total memory across nodes.
+    '''
+    return CONSTANTS['MIN_TOTAL_MEMORY']
+#--- End: def
 
 def TOTAL_MEMORY():
     '''TODO
@@ -773,13 +778,13 @@ def close_files(file_format=None):
     '''
     if file_format is not None:
         if file_format in _file_to_fh:
-            for fh in _file_to_fh[file_format].itervalues():
+            for fh in _file_to_fh[file_format].values():
                 fh.close()
         
             _file_to_fh[file_format].clear()
     else:
-        for file_format, value in _file_to_fh.iteritems():
-            for fh in value.itervalues():
+        for file_format, value in _file_to_fh.items():
+            for fh in value.values():
                 fh.close()
         
             _file_to_fh[file_format].clear()
@@ -830,15 +835,15 @@ def close_one_file(file_format=None):
     '''
     if file_format is not None:
         if file_format in _file_to_fh and _file_to_fh[file_format]:
-            filename, fh = next(_file_to_fh[file_format].iteritems())
+            filename, fh = next(iter(_file_to_fh[file_format].items()))
             fh.close()
             del _file_to_fh[file_format][filename]
     else:    
-        for values in _file_to_fh.itervalues():
+        for values in _file_to_fh.values():
             if not values:
                 continue
         
-            filename, fh = next(values.iteritems())
+            filename, fh = next(iter(values.items()))
             fh.close()
             del values[filename]
 
@@ -886,7 +891,7 @@ def open_files(file_format=None):
             return {}
     else:   
         out = {}
-        for file_format, values in _file_to_fh.iteritems():
+        for file_format, values in _file_to_fh.items():
             out[file_format] = values.copy()
             
         return out
@@ -2459,16 +2464,21 @@ def _DEPRECATION_ERROR(message='', version='3.0.0'):
 
 
 def _DEPRECATION_ERROR_ARG(instance, method, arg, message='', version='3.0.0'):  
-    raise DeprecationError("Argument {2!r} of method '{0}.{1}' has been deprecated at version 3.0.0 and is no longer available. {3}".format(
+    raise DeprecationError("Argument {2!r} of method '{0}.{1}' has been deprecated at version {4} and is no longer available. {3}".format(
             instance.__class__.__name__,
             method,
             arg,
-            message))
+            message,
+            version))
 
 
-def _DEPRECATION_ERROR_FUNCTION_KWARGS(func, kwargs={}, message='',
+def _DEPRECATION_ERROR_FUNCTION_KWARGS(func, kwargs=None, message='',
                                        exact=False, traceback=False,
                                        version='3.0.0'):
+    # Unsafe to set mutable '{}' as default in the func signature.
+    if kwargs is None:  # distinguish from falsy '{}'
+        kwargs = {}
+
     if exact:
         kwargs={'exact': None}
         message = "Use 're.compile' objects instead."
@@ -2478,16 +2488,21 @@ def _DEPRECATION_ERROR_FUNCTION_KWARGS(func, kwargs={}, message='',
         message = "Use keyword 'verbose' instead."
         
     for key in kwargs.keys():
-        raise DeprecationError("Keyword {1!r} of function '{0}' has been deprecated at version 3.0.0 and is no longer available. {2}".format(
+        raise DeprecationError("Keyword {1!r} of function '{0}' has been deprecated at version {3} and is no longer available. {2}".format(
             func,           
             key,
-            message))
+            message,
+            version))
 
     
-def _DEPRECATION_ERROR_KWARGS(instance, method, kwargs={}, message='',
+def _DEPRECATION_ERROR_KWARGS(instance, method, kwargs=None, message='',
                               i=False, traceback=False, axes=False,
                               exact=False, relaxed_identity=False,
                               version='3.0.0'):
+    # Unsafe to set mutable '{}' as default in the func signature.
+    if kwargs is None:  # distinguish from falsy '{}'
+        kwargs = {}
+
     if relaxed_identity:
         kwargs={'relaxed_identity': None}
         message = "Use keywords 'strict' or 'relaxed' instead."
@@ -2510,14 +2525,25 @@ def _DEPRECATION_ERROR_KWARGS(instance, method, kwargs={}, message='',
 
         
     for key in kwargs.keys():
-        raise DeprecationError("Keyword {2!r} of method '{0}.{1}' has been deprecated at version {} and is no longer available. {3}".format(
+        raise DeprecationError("Keyword {2!r} of method '{0}.{1}' has been deprecated at version {4} and is no longer available. {3}".format(
             instance.__class__.__name__,
             method,
             key,
-            version,
-            message))
+            message,
+            version))
 
     
+def _DEPRECATION_ERROR_KWARG_VALUE(instance, method, kwarg, value,
+                                   message='', version='3.0.0'):
+    raise DeprecationError("Value {!r} of keyword {!r} of method '{}.{}' has been deprecated at version {} and is no longer available. {}".format(
+        value,
+        kwarg,
+        method,
+        instance.__class__.__name__,
+        version,
+        message))
+
+
 def _DEPRECATION_ERROR_METHOD(instance, method, message='', version='3.0.0'):
     raise DeprecationError("{} method {!r} has been deprecated at version {} and is no longer available. {}".format(
         instance.__class__.__name__,
@@ -2541,29 +2567,30 @@ def _DEPRECATION_ERROR_FUNCTION(func, message='', version='3.0.0'):
         message))
 
 
-def _DEPRECATION_ERROR_CLASS(cls, message=''):
-    raise DeprecationError("Class {!r} has been deprecated at version 3.0.0 and is no longer available. {}".format(
+def _DEPRECATION_ERROR_CLASS(cls, message='', version='3.0.0'):
+    raise DeprecationError("Class {!r} has been deprecated at version {} and is no longer available. {}".format(
         cls,
+        version,
         message))
 
 
 def _DEPRECATION_WARNING_METHOD(instance, method, message='', new=None, version='3.0.0'):    
     warnings.warn(
-        "{} method {!r} has been deprecated at version 3.0.0 and will be removed in a future version. {}".format(
-            instance.__class__.__name__, method, message),
+        "{} method {!r} has been deprecated at version {} and will be removed in a future version. {}".format(
+            instance.__class__.__name__, method, version, message),
         DeprecationWarning)
 
 
 def _DEPRECATION_ERROR_DICT(message='', version='3.0.0'):
     raise DeprecationError(
-        "Use of a 'dict' to identify constructs has been deprecated and is no longer available. {}".format(
-            message))
+        "Use of a 'dict' to identify constructs has been deprecated at version {} and is no longer available. {}".format(
+            version, message))
 
 
 def _DEPRECATION_ERROR_SEQUENCE(instance, version='3.0.0'):
     raise DeprecationError(
-        "Use of a {!r} to identify constructs has been deprecated and is no longer available. Use the * operator to unpack the arguments instead.".format(
-            instance.__class__.__name__))
+        "Use of a {!r} to identify constructs has been deprecated at version {} and is no longer available. Use the * operator to unpack the arguments instead.".format(
+            instance.__class__.__name__, version))
 
 
 # --------------------------------------------------------------------
@@ -2588,4 +2615,3 @@ def set_equals(x, y, rtol=None, atol=None, ignore_fill_value=False,
 
     '''
     _DEPRECATION_ERROR_FUNCTION('cf.set_equals') # pragma: no cover
-    
