@@ -10,12 +10,11 @@ from ..functions import (_DEPRECATION_ERROR_METHOD,
 
 
 class Properties:
-    '''Mixin class for descriptive properties.
+    '''Mixin class for a container of descriptive properties.
 
     .. versionadded:: 3.0.0
 
     '''
-
     _special_properties = ()
 
     # ----------------------------------------------------------------
@@ -23,14 +22,22 @@ class Properties:
     # ----------------------------------------------------------------
     @property
     def _ATOL(self):
-        '''TODO
+        '''Return the tolerance on absolute differences between real numbers,
+    as returned by the `cf.ATOL` function.
+
+    This is used by, for example, the `_equals` method.
+
         '''
         return ATOL()
 
     
     @property
     def _RTOL(self):
-        '''TODO
+        '''Return the tolerance on relative differences between real numbers,
+    as returned by the `cf.RTOL` function.
+
+    This is used by, for example, the `_equals` method.
+
         '''
         return RTOL()
 
@@ -39,7 +46,26 @@ class Properties:
     # Private methods
     # ----------------------------------------------------------------
     def _matching_values(self, value0, value1, units=False):
-        '''TODO
+        '''Whether two values match.
+
+    The definition of "match" depends on the types of *value0* and
+    *value1*. See the code for the details.
+
+    :Parameters:
+
+        value0:
+            The first value to be matched.
+
+        value1:
+            The second value to be matched.
+
+        units: `bool`, optional
+
+    :Returns:
+
+        `bool`
+            Whether or not the two values match.
+
         '''
         if value1 is None:            
             return False
@@ -48,7 +74,7 @@ class Properties:
             return bool(value0.evaluate(value1)) # TODO vectors
 
         try:
-            # re.compile object
+            # value0 is a re.compile object
             return bool(value0.search(value1))
         except (AttributeError, TypeError):
             if units and isinstance(value0, str):
@@ -480,11 +506,11 @@ class Properties:
     def get_property(self, prop, default=ValueError()):
         '''Get a CF property.
         
+    .. versionadded:: 3.0.0
+
     .. seealso:: `clear_properties`, `del_property`, `has_property`,
                  `properties`, `set_property`
     
-    .. versionadded:: 3.0.0
-
     :Parameters:
     
         prop: `str`
@@ -536,11 +562,11 @@ class Properties:
     def has_property(self, prop):
         '''Whether a property has been set.
 
+    .. versionadded:: 3.0.0
+    
     .. seealso:: `clear_properties`, `del_property`, `get_property`,
                  `properties`, `set_property`
     
-    .. versionadded:: 3.0.0
-    
     :Parameters:
     
         prop: `str`
@@ -582,11 +608,11 @@ class Properties:
     def del_property(self, prop, default=ValueError()):
         '''Remove a property.
 
+    .. versionadded:: 3.0.0
+    
     .. seealso:: `clear_properties`, `get_property`, `has_property`,
                  `properties`, `set_property`
     
-    .. versionadded:: 3.0.0
-    
     :Parameters:
     
         prop: `str`
@@ -636,34 +662,13 @@ class Properties:
         return super().del_property(prop, default=default)
 
 
-    def match(self, *identities, **kwargs):
-        '''Alias for `match_by_identity`.
-
-        '''
-        if kwargs:                    
-            _DEPRECATION_ERROR_KWARGS(self, 'match', kwargs,
-                                      "Use 'match_by_*' methods instead.") # pragma: no cover
-
-        if identities and isinstance(identities[0], (list, tuple, set)):
-            _DEPRECATION_ERROR(
-                "Use of a {!r} for identities has been deprecated. Use the * operator to unpack the arguments instead.".format(
-                    identities[0].__class__.__name__)) # pragma: no cover
-            
-        for i in identities:
-           if isinstance(i, dict):
-                _DEPRECATION_ERROR_DICT("Use 'match_by_*' methods instead.") # pragma: no cover
-        #--- End: for
-
-        return self.match_by_identity(*identities)
-
-
     def match_by_identity(self, *identities):
         '''Whether or not the construct identity satisfies conditions.
 
-    .. seealso:: `match`, `match_by_property`, `match_by_ncvar`
-    
     .. versionadded:: 3.0.0
     
+    .. seealso:: `match`, `match_by_property`, `match_by_ncvar`
+    
     :Parameters:
     
         identities: optional
@@ -684,7 +689,12 @@ class Properties:
             construct ``x`` has six identities:
     
                >>> x.identities()
-               ['time', 'long_name=Time', 'foo=bar', 'standard_name=time', 'ncvar%t', T']
+               ['time',
+                'long_name=Time',
+                'foo=bar',
+                'standard_name=time',
+                'ncvar%t',
+                'T']
         
     :Returns:
     
@@ -723,12 +733,12 @@ class Properties:
 
 
     def match_by_ncvar(self, *ncvars):
-        '''Whether or not the construct has a netCDF variable name.
+        '''Whether or not the netCDF variable name satisfies conditions.
 
-    .. seealso:: `match`, `match_by_identity`, `match_by_property`
-    
     .. versionadded:: 3.0.0
     
+    .. seealso:: `match`, `match_by_identity`, `match_by_property`
+    
     :Parameters:
     
         ncvars: optional
@@ -751,11 +761,19 @@ class Properties:
     
     **Examples:**
     
-    >>> f.match_by_ncvar('t')
-    
-    >>> f.match_by_ncvar(re.compile('^t'))
-    
+    >>> f.nc_get_variable()
+    'time'
+    >>> f.match_by_ncvar('time')
+    True
     >>> f.match_by_ncvar('t', 'time')
+    True
+    >>> f.match_by_ncvar('t')
+    False
+    >>> f.match_by_ncvar()
+    True
+    >>> import re
+    >>> f.match_by_ncvar(re.compile('^t'))
+    True
 
         '''
         if not ncvars:
@@ -782,10 +800,10 @@ class Properties:
     def match_by_property(self, *mode, **properties):
         '''Whether or not properties satisfy conditions.
 
-    .. seealso:: `match`, `match_by_identity`, `match_by_ncvar`
-
     .. versionadded:: 3.0.0
     
+    .. seealso:: `match`, `match_by_identity`, `match_by_ncvar`
+
     :Parameters:
     
         mode: optional
@@ -840,9 +858,11 @@ class Properties:
     >>> f.match_by_property(standard_name='longitude', foo='cf.set(['bar', 'not_bar'])
     
     >>> f.match_by_property(long_name=re.compile('^lon'))
-    
+
         '''
         _or = False
+
+        # Parse mode
         if mode:
             if len(mode) > 1:
                 raise ValueError("Can provide at most one positional argument")
@@ -928,10 +948,10 @@ class Properties:
     def set_properties(self, properties, copy=True):
         '''Set properties.
 
-    .. seealso:: `clear_properties`, `properties`, `set_property`
-    
     .. versionadded:: 3.0.0
     
+    .. seealso:: `clear_properties`, `properties`, `set_property`
+    
     :Parameters:
     
         properties: `dict` 
@@ -982,11 +1002,11 @@ class Properties:
     def set_property(self, prop, value, copy=True):
         '''Set a property.
 
+    .. versionadded:: 3.0.0
+
     .. seealso:: `clear_properties`, `del_property`, `get_property`,
                  `has_property`, `properties`
     
-    .. versionadded:: 3.0.0
-
     :Parameters:
 
         prop: `str`
@@ -1031,6 +1051,29 @@ class Properties:
         return super().set_property(prop, value, copy=copy)
 
 
+    # ----------------------------------------------------------------
+    # Aliases
+    # ----------------------------------------------------------------
+    def match(self, *identities, **kwargs):
+        '''Alias for `match_by_identity`.
+
+        '''
+        if kwargs:                    
+            _DEPRECATION_ERROR_KWARGS(self, 'match', kwargs,
+                                      "Use 'match_by_*' methods instead.") # pragma: no cover
+
+        if identities and isinstance(identities[0], (list, tuple, set)):
+            _DEPRECATION_ERROR(
+                "Use of a {!r} for identities has been deprecated. Use the * operator to unpack the arguments instead.".format(
+                    identities[0].__class__.__name__)) # pragma: no cover
+            
+        for i in identities:
+           if isinstance(i, dict):
+                _DEPRECATION_ERROR_DICT("Use 'match_by_*' methods instead.") # pragma: no cover
+        #--- End: for
+
+        return self.match_by_identity(*identities)
+
     # ----------------------------------------------------------------
     # Deprecated attributes and methods
     # ----------------------------------------------------------------
