@@ -26,144 +26,10 @@ class PropertiesDataBounds(PropertiesData):
     bounds.
 
     '''
-    # Define the reserved attributes. These are methods which can't be
-    # overwritten, as well as a few attributes.
-    _reserved_attrs = ('_reserved_attrs',
-                       '_insert_data'
-                       'binary_mask',
-                       'chunk',
-                       'clip',
-                       'copy',
-                       'cos',
-                       'dump',
-                       'equals',
-                       'identity',
-                       'match',
-                       'name',
-                       'override_units',
-                       'select',
-                       'sin',
-                       'subspace',
-                       'where',
-                       )
-
-#    def __init__(self, properties=None, data=None, bounds=None,
-#                 geometry=None, interior_ring=None, source=None,
-#                 copy=True, _use_data=True):
-#        '''**Initialization**
-#
-#    :Parameters:
-#    
-#        properties: `dict`, optional
-#            Set descriptive properties. The dictionary keys are
-#            property names, with corresponding values. Ignored if the
-#            *source* parameter is set.
-#    
-#            *Parameter example:*
-#               ``properties={'standard_name': 'longitude'}``
-#            
-#            Properties may also be set after initialisation with the
-#            `set_properties` and `set_property` methods.
-#      
-#        data: `Data`, optional
-#            Set the data array. Ignored if the *source* parameter is
-#            set.
-#            
-#            The data array may also be set after initialisation with
-#            the `set_data` method.
-#      
-#        bounds: `Bounds`, optional
-#            Set the bounds array. Ignored if the *source* parameter is
-#            set.
-#            
-#            The bounds array may also be set after initialisation with
-#            the `set_bounds` method.
-#      
-#        geometry: `str`, optional
-#            Set the geometry type. Ignored if the *source* parameter
-#            is set.
-#            
-#            *Parameter example:*
-#               ``geometry='polygon'``
-#            
-#            The geometry type may also be set after initialisation
-#            with the `set_geometry` method.
-#      
-#        interior_ring: `InteriorRing`, optional
-#            Set the interior ring variable. Ignored if the *source*
-#            parameter is set.
-#            
-#            The interior ring variable may also be set after
-#            initialisation with the `set_interior_ring` method.
-#      
-#        source: optional
-#            Initialize the properties, geometry type, data, bounds and
-#            interior ring from those of *source*.
-#     
-#        copy: `bool`, optional
-#            If False then do not deep copy input parameters prior to
-#            initialization. By default arguments are deep copied.
-#
-#        '''
-#        if _use_data and data is not None and properties:
-#            if not data.Units:
-#                units = properties.get('units')
-#                if units is not None:
-#                    data = data.override_units(Units(units, properties.get('calendar')))
-#        #--- End: if
-#        
-#        super().__init__(properties=properties, data=data,
-#                         bounds=bounds, source=source,
-#                         geometry=geometry,
-#                         interior_ring=interior_ring, copy=copy,
-#                         _use_data=_use_data)
-#
-#        # Initialise properties and data
-#        super().__init__(properties=properties, data=data,
-#                         source=source, copy=copy,
-#                         _use_data=_use_data)
-#
-#        # Get bounds, geometry type and interior ring from source
-#        if source is not None:
-#            try:
-#                bounds = source.get_bounds(None)
-#            except AttributeError:
-#                bounds = None
-#                
-#            try:
-#                geometry = source.get_geometry(None)
-#            except AttributeError:
-#                geometry = None
-#                
-#            try:
-#                interior_ring = source.get_interior_ring(None)
-#            except AttributeError:
-#                interior_ring = None
-#        #--- End: if
-#
-#        # Initialise bounds
-#        if bounds is not None:
-#            if copy or not _use_data:
-#                bounds = bounds.copy(data=_use_data)
-#                
-#            self.set_bounds(bounds, copy=False)
-#
-#        # Initialise the geometry type
-#        if geometry is not None:
-#            self.set_geometry(geometry)
-#            
-#        # Initialise interior ring
-#        if interior_ring is not None:
-#            if copy or not _use_data:
-#                interior_ring = interior_ring.copy(data=_use_data)
-#                
-#            self.set_interior_ring(interior_ring, copy=False)
-
-
     def __getitem__(self, indices):
         '''Return a subspace of the field construct defined by indices.
 
-        x.__getitem__(indices) <==> x[indices]
+    x.__getitem__(indices) <==> x[indices]
 
         '''
         if indices is Ellipsis:
@@ -194,7 +60,6 @@ class PropertiesDataBounds(PropertiesData):
                         "Can't do a cyclic slice on a non-cyclic axis")
 
                 new = new.roll(iaxis, shift)
-            #--- End: for
         else:
             new = self.copy() #data=False)
 
@@ -450,7 +315,7 @@ class PropertiesDataBounds(PropertiesData):
     broadcasting rules.
     
     If the construct has bounds then they are operated on with the
-    same data as the the construct's data.
+    same data as the construct's data.
     
     It is intended to be called by the binary arithmetic and comparison
     methods, such as `!__sub__` and `!__lt__`.
@@ -586,6 +451,59 @@ class PropertiesDataBounds(PropertiesData):
         out.del_bounds(None)
         return out
 
+    
+    def _matching_values(self, value0, value1, units=False):
+        '''TODO
+
+        '''
+        if value1 is None:            
+            return False
+
+        if units and isinstance(value0, str):
+            return Units(value0).equals(Units(value1))
+        
+        if isinstance(value0, Query):
+            return bool(value0.evaluate(value1)) # TODO vectors
+        else:
+            try:
+                return value0.search(value1)
+            except (AttributeError, TypeError):
+                return self._equals(value1, value0)
+        #--- End: if
+
+        return False
+
+    
+    def _apply_data_operation(
+            self, oper_name, *oper_args, bounds=True, inplace=False,
+            i=False, **oper_kwargs):
+        '''Define an operation that can be applied to the data array.
+
+        * 'oper_name' should be the string name for the desired operation
+          as it is defined (its method name) under the Data class, e.g.
+          'sin' to apply 'Data.sin'
+        * any positional or keyword arguments required in the operation
+          call should be passed through via *oper_args and **oper_kwargs.
+        '''
+        if i:
+            _DEPRECATION_ERROR_KWARGS(self, oper_name, i=True) # pragma: no cover
+ 
+        v = getattr(super(), oper_name)(*oper_args, inplace=inplace,
+                                        **oper_kwargs)
+        if inplace:
+            v = self
+
+        if bounds:
+            bounds = v.get_bounds(None)
+            if bounds is not None:
+                getattr(bounds, oper_name)(*oper_args, inplace=True,
+                                           **oper_kwargs)
+        #--- End: if
+
+        if inplace:
+            v = None
+        return v
+
 
     # ----------------------------------------------------------------
     # Attributes
@@ -732,6 +650,43 @@ class PropertiesDataBounds(PropertiesData):
             "Can't get lower bounds when there are no bounds nor coordinate data")
 
 
+    @property
+    def Units(self):
+        '''The `cf.Units` object containing the units of the data array.
+
+    Stores the units and calendar CF properties in an internally
+    consistent manner. These are mirrored by the `units` and
+    `calendar` CF properties respectively.
+    
+    **Examples:**
+    
+    >>> f.Units
+    <Units: K>
+    
+    >>> f.Units
+    <Units: days since 2014-1-1 calendar=noleap>
+
+        '''
+        return super().Units
+    @Units.setter
+    def Units(self, value):
+        PropertiesData.Units.fset(self, value)
+
+        # Set the Units on the bounds
+        bounds = self.get_bounds(None)
+        if bounds is not None:
+            bounds.Units = value
+
+        # Set the Units on the period
+        period = self._custom.get('period')
+        if period is not None:
+            period = period.copy()
+            period.Units = value
+            self._custom['period'] = period
+    @Units.deleter
+    def Units(self):
+        PropertiesData.Units.fdel(self)
+
     @property
     def upper_bounds(self):
         '''The upper bounds of cells.
@@ -803,7 +758,7 @@ class PropertiesDataBounds(PropertiesData):
     
     :Returns:
     
-    TODO
+            The construct with masked elements.
     
     **Examples:**
     
@@ -835,17 +790,9 @@ class PropertiesDataBounds(PropertiesData):
     [1.  -- ]
 
         '''
-        v = super().mask_invalid(inplace=inplace, i=i)
-        if inplace:
-            v = self
-
-        bounds = v.get_bounds(None)
-        if bounds is not None:
-            bounds.mask_invalid(inplace=True)
-
-        if inplace:
-            v = None
-        return v
+        # Set bounds to True to bypass 'if bounds' check in call:
+        return self._apply_data_operation(
+            'mask_invalid', bounds=True, inplace=inplace, i=i)
 
 
     # ----------------------------------------------------------------
@@ -884,25 +831,25 @@ dtype('float64')
 >>> type(f.dtype)
 <type 'numpy.dtype'>
 
->>> print f.array
+>>> print(f.array)
 [0.5 1.5 2.5]
 >>> import numpy
 >>> f.dtype = numpy.dtype(int)
->>> print f.array
+>>> print(f.array)
 [0 1 2]
 >>> f.dtype = bool
->>> print f.array
+>>> print(f.array)
 [False  True  True]
 >>> f.dtype = 'float64'
->>> print f.array
+>>> print(f.array)
 [ 0.  1.  1.]
 
->>> print f.array
+>>> print(f.array)
 [0.5 1.5 2.5]
 >>> f.dtype = int
 >>> f.dtype = bool
 >>> f.dtype = float
->>> print f.array
+>>> print(f.array)
 [ 0.5  1.5  2.5]
 
         '''
@@ -970,22 +917,8 @@ dtype('float64')
     [-1. -1. -1. -1.  0.  1.  2.  2.  2.]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'ceil', i=True) # pragma: no cover
-
-        v = super().ceil(inplace=inplace)
-        if inplace:
-            v = self
-            
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.ceil(inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'ceil', bounds=bounds, inplace=inplace, i=i)
 
 
     def chunk(self, chunksize=None):
@@ -1061,22 +994,9 @@ dtype('float64')
     >>> g = f.clip(-90, 90, 'degrees_north')
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'clip', i=True) # pragma: no cover
-
-        v = super().clip(a_min, a_max, units=units, inplace=inplace)
-        if inplace:
-            v = self
-            
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.clip(a_min, a_max, units=units, inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'clip', a_min, a_max, bounds=bounds, inplace=inplace, i=i,
+            units=units)
 
     
     def close(self):
@@ -1115,7 +1035,7 @@ dtype('float64')
     
     :Returns:
     
-    TODO
+        TODO
         '''
         variable0 = variables[0]
 
@@ -1137,12 +1057,12 @@ dtype('float64')
     def cos(self, bounds=True, inplace=False,  i=False):
         '''Take the trigonometric cosine of the data, element-wise.
 
-    Units are accounted for in the calculation, so that the the cosine
+    Units are accounted for in the calculation, so that the cosine
     of 90 degrees_east is 0.0, as is the cosine of 1.57079632
     radians. If the units are not equivalent to radians (such as
     Kelvin) then they are treated as if they were radians.
-    
-    The output units are '1' (nondimensionsal).
+
+    The output units are '1' (nondimensional).
     
     .. seealso:: `sin`, `tan`
     
@@ -1186,22 +1106,8 @@ dtype('float64')
     [[0.540302305868 -0.416146836547 -0.9899924966 --]]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'cos', i=True) # pragma: no cover
-
-        v = super().cos(inplace=inplace)
-        if inplace:
-            v = self
-
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.cos(inplace=True)
-        #--- End: if
-        
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'cos', bounds=bounds, inplace=inplace, i=i)
 
 
     def cyclic(self, axes=None, iscyclic=True):
@@ -1225,7 +1131,7 @@ dtype('float64')
     
     **Examples:**
     
-    TODO
+        TODO
 
         '''
         out = super().cyclic(axes, iscyclic)
@@ -1424,7 +1330,7 @@ dtype('float64')
     
         units: `Units`, optional
             The reference time units to convert to. By default the
-            units days since the original reference time in the the
+            units days since the original reference time in the
             original calendar.
     
             *Parameter example:*
@@ -1480,26 +1386,9 @@ dtype('float64')
     <Units: days since 2000-1-1>
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'convert_reference_time', i=True) # pragma: no cover
-
-        v = super().convert_reference_time(units=units,
-                                           calendar_months=calendar_months,
-                                           calendar_years=calendar_years,
-                                           inplace=inplace)
-        if inplace:
-            v = self
-
-        bounds = v.get_bounds(None)
-        if bounds is not None:
-            bounds.convert_reference_time(units=units,
-                                          calendar_months=calendar_months,
-                                          calendar_years=calendar_years,
-                                          inplace=True)
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'convert_reference_time', inplace=inplace, i=i, units=units,
+            calendar_months=calendar_months, calendar_years=calendar_years)
 
     
     def flatten(self, axes=None, inplace=False):
@@ -1552,6 +1441,9 @@ dtype('float64')
     (4, 2, 3)
 
         '''
+        # Note the 'axes' argument can change mid-method meaning it is not
+        # possible to consolidate this method using a call to
+        # _apply_data_operations, despite having mostly the same logic.
         v = super().flatten(axes, inplace=inplace)
         if inplace:
             v = self
@@ -1603,22 +1495,8 @@ dtype('float64')
     [-2. -2. -2. -1.  0.  1.  1.  1.  1.]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'floor', i=True) # pragma: no cover
-
-        v = super().floor(inplace=inplace)
-        if inplace:
-            v = self
-            
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.floor(inplace=True)
-        #--- End: if
-        
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'floor', bounds=bounds, inplace=inplace, i=i)
 
 
     def direction(self):
@@ -1633,34 +1511,13 @@ dtype('float64')
             
     **Examples:**
     
-    >>> print c.direction()
+    >>> print(c.direction())
     None
     
             ''' 
         return
 
-    
-    def _matching_values(self, value0, value1, units=False):
-        '''TODO
-        '''
-        if value1 is None:            
-            return False
 
-        if units and isinstance(value0, str):
-            return Units(value0).equals(Units(value1))
-        
-        if isinstance(value0, Query):
-            return bool(value0.evaluate(value1)) # TODO vectors
-        else:
-            try:
-                return value0.search(value1)
-            except (AttributeError, TypeError):
-                return self._equals(value1, value0)
-        #--- End: if
-
-        return False
-
-    
     def match_by_property(self, *mode, **properties):
         '''Determine whether or not a variable satisfies conditions.
 
@@ -1727,6 +1584,8 @@ dtype('float64')
     
     **Examples:**
 
+        TODO
+
         '''
         # Return all constructs if no identities have been provided
         if not identities:
@@ -1786,33 +1645,21 @@ dtype('float64')
     >>> g = f.override_calendar('noleap')
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'override_calendar', i=True) # pragma: no cover
-
-        v = super().override_calendar(calendar, inplace=inplace)
-        if inplace:
-            v = self
-
-        bounds = v.get_bounds(None)
-        if bounds is not None:
-            bounds.override_calendar(calendar, inplace=True)
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'override_calendar', calendar, inplace=inplace, i=i)
 
 
     def override_units(self, units, inplace=False, i=False):
         '''Override the units.
 
-    The new units **need not** be equivalent to the original ones and
-    the data array elements will not be changed to reflect the new
+    The new units need not be equivalent to the original ones, and the
+    data array elements will not be changed to reflect the new
     units. Therefore, this method should only be used when it is known
     that the data array values are correct but the units have
     incorrectly encoded.
     
-    Not to be confused with setting `units` or `Units` attributes to
-    units which are equivalent to the original units.
+    Not to be confused with setting the `units` or `Units` attribute
+    to units which are equivalent to the original units.
     
     .. seealso:: `calendar`, `override_calendar`, `units`, `Units`
     
@@ -1829,7 +1676,7 @@ dtype('float64')
     
     :Returns:
     
-    TODO
+            TODO
     
     **Examples:**
     
@@ -1848,21 +1695,9 @@ dtype('float64')
     >>> f.datum(0)
     100000.0
 
-        '''        
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'override_units', i=True) # pragma: no cover
-
-        v = super().override_units(units, inplace=inplace)
-        if inplace:
-            v = self
-
-        bounds = v.get_bounds(None)
-        if bounds is not None:
-            bounds.override_units(units, inplace=True)
-
-        if inplace:
-            v = None
-        return v
+        '''
+        return self._apply_data_operation(
+            'override_units', units, inplace=inplace, i=i)
 
 
     def files(self):
@@ -1945,7 +1780,7 @@ dtype('float64')
             #
             # As per section 7.1 in the CF conventions: i) if the
             # variable is 0 or 1 dimensional then flip all dimensions
-            # (including the the trailing size 2 dimension); ii) if
+            # (including the trailing size 2 dimension); ii) if
             # the variable has 2 or more dimensions then do not flip
             # the trailing dimension.
             # --------------------------------------------------------
@@ -2009,22 +1844,8 @@ dtype('float64')
     ValueError: Can't take exponential of dimensional quantities: <Units: kg m-1 s-2>
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'exp', i=True) # pragma: no cover
-         
-        v = super().exp(inplace=inplace)
-        if inplace:
-            v = self
-    
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.exp(inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'exp', bounds=bounds, inplace=inplace, i=i)
 
 
     def set_bounds(self, bounds, copy=True):
@@ -2107,12 +1928,12 @@ dtype('float64')
     def sin(self, bounds=True, inplace=False, i=False):
         '''The trigonometric sine of the data, element-wise.
 
-    Units are accounted for in the calculation. For example, the the
+    Units are accounted for in the calculation. For example, the
     sine of 90 degrees_east is 1.0, as is the sine of 1.57079632
     radians. If the units are not equivalent to radians (such as
     Kelvin) then they are treated as if they were radians.
     
-    The Units are changed to '1' (nondimensionsal).
+    The Units are changed to '1' (nondimensional).
     
     .. seealso:: `cos`, `tan`
     
@@ -2147,7 +1968,7 @@ dtype('float64')
     
     >>> f.Units
     <Units: m s-1>
-    >>> print f.array
+    >>> print(f.array)
     [[1 2 3 --]]
     >>> f.sin()
     >>> f.Units
@@ -2156,36 +1977,267 @@ dtype('float64')
     [[0.841470984808 0.909297426826 0.14112000806 --]]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'sin', i=True) # pragma: no cover
+        return self._apply_data_operation(
+            'sin', bounds=bounds, inplace=inplace, i=i)
 
-        v = super().sin(inplace=inplace)
-        if inplace:
-            v = self
-        
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.sin(inplace=True)
-        #--- End: if
 
-        if inplace:
-            v = None            
-        return v
+    def arctan(self, bounds=True, inplace=False):
+        '''Take the trigonometric inverse tangent of the data element-wise.
+
+    Units are ignored in the calculation. The result has units of radians.
+
+    The "standard_name" and "long_name" properties are removed from
+    the result.
+
+    .. versionadded:: 3.0.7
+
+    .. seealso:: `tan`
+    
+    :Parameters:
+    
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+    
+    :Returns:
+    
+            The construct with the trigonometric inverse tangent of data
+            values. If the operation was in-place then `None` is returned.
+    
+    **Examples:**
+    
+    >>> d = cf.Data([[0, 1, 2], [3, -99, 5]], mask=[[0, 0, 0], [0, 1, 0]])
+    >>> print(d.array)
+    [[0  1 2]
+     [3 -- 5]]
+    >>> e = d.arctan()
+    >>> e
+    <CF Data(2, 3): [[0.0, ..., 1.373400766945016]] radians>
+    >>> print(e.array)
+    [[0.0                0.7853981633974483 1.1071487177940904]
+     [1.2490457723982544                 -- 1.373400766945016 ]]
+
+        '''
+        return self._apply_data_operation(
+            'arctan', bounds=bounds, inplace=inplace)
+
+
+    def arcsinh(self, bounds=True, inplace=False):
+        '''Take the inverse hyperbolic sine of the data element-wise.
+
+    Units are ignored in the calculation. The result has units of radians.
+
+    The "standard_name" and "long_name" properties are removed from
+    the result.
+
+    .. versionadded:: 3.1.0
+
+    .. seealso:: `sinh`
+
+    :Parameters:
+
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+
+    :Returns:
+    
+            The construct with the inverse hyperbolic sine of data values.
+            If the operation was in-place then `None` is returned.
+
+    **Examples:**
+
+    >>> d = cf.Data([[0, 1, 2], [3, -99, 5]], mask=[[0, 0, 0], [0, 1, 0]])
+    >>> print(d.array)
+    [[0  1 2]
+     [3 -- 5]]
+    >>> e = d.arcsinh()
+    >>> e
+    <CF Data(2, 3): [[0.0, ..., 2.3124383412727525]] radians>
+    >>> print(e.array)
+    [[0.0 0.881373587019543 1.4436354751788103]
+     [1.8184464592320668 -- 2.3124383412727525]]
+
+        '''
+        return self._apply_data_operation(
+            'arcsinh', bounds=bounds, inplace=inplace)
+
+
+    def tanh(self, bounds=True, inplace=False):
+        '''Take the hyperbolic tangent of the data array.
+
+    Units are accounted for in the calculation. If the units are not
+    equivalent to radians (such as Kelvin) then they are treated as if
+    they were radians. For example, the the hyperbolic tangent of 90
+    degrees_east is 0.91715234, as is the hyperbolic tangent of
+    1.57079632 radians.
+
+    The output units are changed to '1' (nondimensional).
+
+    The "standard_name" and "long_name" properties are removed from
+    the result.
+
+    .. versionadded:: 3.1.0
+
+    .. seealso:: `sinh`, `cosh`
+
+
+    :Parameters:
+
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+
+    :Returns:
+    
+            The construct with the hyperbolic tangent of data values. If the
+            operation was in-place then `None` is returned.
+
+    **Examples:**
+
+    >>> d.Units
+    <Units: degrees_north>
+    >>> print(d.array)
+    [[-90 0 90 --]]
+    >>> e = d.tanh()
+    >>> e.Units
+    <Units: 1>
+    >>> print(e.array)
+    [[-0.9171523356672744 0.0 0.9171523356672744 --]]
+
+    >>> d.Units
+    <Units: m s-1>
+    >>> print(d.array)
+    [[1 2 3 --]]
+    >>> d.tanh(inplace=True)
+    >>> d.Units
+    <Units: 1>
+    >>> print(d.array)
+    [[0.7615941559557649 0.9640275800758169 0.9950547536867305 --]]
+
+        '''
+        return self._apply_data_operation(
+            'tanh', bounds=bounds, inplace=inplace)
+
+
+    def sinh(self, bounds=True, inplace=False):
+        '''Take the hyperbolic sine of the data array in place.
+
+    Units are accounted for in the calculation. If the units are not
+    equivalent to radians (such as Kelvin) then they are treated as if
+    they were radians. For example, the the hyperbolic sine of 90
+    degrees_north is 2.30129890, as is the hyperbolic sine of
+    1.57079632 radians.
+
+    The output units are changed to '1' (nondimensional).
+
+    The "standard_name" and "long_name" properties are removed from
+    the result.
+
+    .. versionadded:: 3.1.0
+
+    .. seealso:: `arcsinh`, `cosh`, `tanh`
+
+    :Parameters:
+
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+
+    :Returns:
+    
+            The construct with the hyperbolic sine of data values. If the
+            operation was in-place then `None` is returned.
+
+    **Examples:**
+
+    >>> d.Units
+    <Units: degrees_north>
+    >>> print(d.array)
+    [[-90 0 90 --]]
+    >>> d.sinh(inplace=True)
+    >>> d.Units
+    <Units: 1>
+    >>> print(d.array)
+    [[-2.3012989023072947 0.0 2.3012989023072947 --]]
+
+    >>> d.Units
+    <Units: m s-1>
+    >>> print(d.array)
+    [[1 2 3 --]]
+    >>> d.sinh(inplace=True)
+    >>> d.Units
+    <Units: 1>
+    >>> print(d.array)
+    [[1.1752011936438014 3.626860407847019 10.017874927409903 --]]
+
+        '''
+        return self._apply_data_operation(
+            'sinh', bounds=bounds, inplace=inplace)
+
+
+    def cosh(self, bounds=True, inplace=False):
+        '''Take the hyperbolic cosine of the data array in place.
+
+    Units are accounted for in the calculation. If the units are not
+    equivalent to radians (such as Kelvin) then they are treated as if
+    they were radians. For example, the the hyperbolic cosine of 0
+    degrees_east is 1.0, as is the hyperbolic cosine of 1.57079632 radians.
+
+    The output units are changed to '1' (nondimensional).
+
+    The "standard_name" and "long_name" properties are removed from
+    the result.
+
+    .. versionadded:: 3.1.0
+
+    .. seealso:: `sinh`, `tanh`
+
+    :Parameters:
+
+        inplace: `bool`, optional
+            If True then do the operation in-place and return `None`.
+
+    :Returns:
+    
+            The construct with the hyperbolic cosine of data values. If the
+            operation was in-place then `None` is returned.
+
+    **Examples:**
+
+    >>> d.Units
+    <Units: degrees_north>
+    >>> print(d.array)
+    [[-90 0 90 --]]
+    >>> e = d.cosh()
+    >>> e.Units
+    <Units: 1>
+    >>> print(e.array)
+    [[2.5091784786580567 1.0 2.5091784786580567 --]]
+
+    >>> d.Units
+    <Units: m s-1>
+    >>> print(d.array)
+    [[1 2 3 --]]
+    >>> d.cosh(inplace=True)
+    >>> d.Units
+    <Units: 1>
+    >>> print(d.array)
+    [[1.5430806348152437 3.7621956910836314 10.067661995777765 --]]
+
+        '''
+        return self._apply_data_operation(
+            'cosh', bounds=bounds, inplace=inplace)
 
 
     def tan(self, bounds=True, inplace=False, i=False):
         '''The trigonometric tangent of the data, element-wise.
 
-    Units are accounted for in the calculation, so that the the
-    tangent of 180 degrees_east is 0.0, as is the sine of
+    Units are accounted for in the calculation, so that the
+    tangent of 180 degrees_east is 0.0, as is the tangent of
     3.141592653589793 radians. If the units are not equivalent to
     radians (such as Kelvin) then they are treated as if they were
     radians.
     
-    The Units are changed to '1' (nondimensionsal).
+    The Units are changed to '1' (nondimensional).
     
-    .. seealso:: `cos`, `sin`
+    .. seealso:: `arctan`, `cos`, `sin`
     
     :Parameters:
     
@@ -2196,36 +2248,36 @@ dtype('float64')
         inplace: `bool`, optional
             If True then do the operation in-place and return `None`.
     
-        i: deprecated at version 3.0.0
-            Use *inplace* parameter instead.
-    
     :Returns:
             
             The construct with the tangent of data values. If the
             operation was in-place then `None` is returned.
     
     **Examples:**
+
+    >>> f.Units
+    <Units: degrees_north>
+    >>> print(f.array)
+    [[-45 0 45 --]]
+    >>> f.tan(inplace=True)
+    >>> f.Units
+    <Units: 1>
+    >>> print(f.array)
+    [[-1.0 0.0 1.0 --]]
     
-    TODO
+    >>> f.Units
+    <Units: m s-1>
+    >>> print(f.array)
+    [[1 2 3 --]]
+    >>> e = f.tan()
+    >>> e.Units
+    <Units: 1>
+    >>> print(e.array)
+    [[1.55740772465 -2.18503986326 -0.142546543074 --]]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'tan', i=True) # pragma: no cover  
-
-        v = super().tan(inplace=inplace)
-        if inplace:
-            v = self
-            
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.tan(inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None
-            
-        return v
+        return self._apply_data_operation(
+            'tan', bounds=bounds, inplace=inplace, i=i)
 
 
     def log(self, base=None, bounds=True, inplace=False, i=False):
@@ -2282,22 +2334,8 @@ dtype('float64')
     ValueError: Can't take the logarithm to the base 2.718281828459045 of <Units: >
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'tan', i=True) # pragma: no cover
-
-        v = super().log(base=base, inplace=inplace)
-        if inplace:
-            v = self
-    
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.log(base=base, inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None    
-        return v
+        return self._apply_data_operation(
+            'log', bounds=bounds, inplace=inplace, i=i)
 
 
     def squeeze(self, axes=None, inplace=False, i=False):
@@ -2381,22 +2419,8 @@ dtype('float64')
     [-1. -1. -1. -1.  0.  1.  1.  1.  1.]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'trunc', i=True) # pragma: no cover
-
-        v = super().trunc(inplace=inplace)
-        if inplace:
-            v = self
-
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.trunc(inplace=True)
-        #--- End: if
-        
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'trunc', bounds=bounds, inplace=inplace, i=i)
 
     
     def identities(self):
@@ -2489,15 +2513,13 @@ dtype('float64')
             default parameter.
     
         strict: `bool`, optional 
-            If True then only take the identity from the
-            "standard_name" property or the "id" attribute, in that
-            order.
+            If True then the identity is the first found of only the
+            "standard_name" property or the "id" attribute.
 
         relaxed: `bool`, optional
-            If True then only take the identity from the
+            If True then the identity is the first found of only the
             "standard_name" property, the "id" attribute, the
-            "long_name" property or netCDF variable name, in that
-            order.
+            "long_name" property or the netCDF variable name.
 
         nc_only: `bool`, optional       
             If True then only take the identity from the netCDF
@@ -2614,22 +2636,8 @@ dtype('float64')
     [-2. -2. -1. -1.  0.  1.  1.  2.  2.]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'rint', i=True) # pragma: no cover
-            
-        v = super().rint(inplace=inplace)
-        if inplace:
-            v = self
-            
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.rint(inplace=True)
-        #--- End: if
-
-        if inplace:
-            v = None            
-        return v
+        return self._apply_data_operation(
+            'rint', bounds=bounds, inplace=inplace, i=i)
 
 
     def round(self, decimals=0, bounds=True, inplace=False, i=False):
@@ -2682,23 +2690,9 @@ dtype('float64')
     [-0., -0., -0., -0.,  0.,  0.,  0.,  0.,  0.]
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'round', i=True)  # pragma: no cover
-
-        v = super().round(decimals=decimals, inplace=inplace)
-        if inplace:
-            v = self
-
-        # Roll the bounds, if there are any
-        if bounds:
-            bounds = v.get_bounds(None)
-            if bounds is not None:
-                bounds.round(decimals=decimals, inplace=True)
-        #--- End: if
-        
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'round', bounds=bounds, inplace=inplace, i=i,
+            decimals=decimals)
 
 
     def roll(self, iaxis, shift, inplace=False, i=False):
@@ -2726,22 +2720,8 @@ dtype('float64')
     TODO
 
         '''
-        if i:
-            _DEPRECATION_ERROR_KWARGS(self, 'roll', i=True) # pragma: no cover
-
-        v = super().roll(iaxis, shift, inplace=inplace)
-        if inplace:
-            v = self
-            
-        # Roll the bounds, if there are any
-        bounds = v.get_bounds(None)
-        if bounds is not None:
-            iaxis = self._parse_axes([iaxis])[0]
-            bounds.roll(iaxis, shift, inplace=True)
-
-        if inplace:
-            v = None
-        return v
+        return self._apply_data_operation(
+            'roll', iaxis, shift, inplace=inplace, i=i)
 
 
     # ----------------------------------------------------------------
