@@ -76,7 +76,7 @@ def read(files, external=None, verbose=False, warnings=False,
     at which time it is automatically deleted. The CDL file may omit
     data array values (as would be the case, for example, if the file
     was created with the ``-h`` or ``-c`` option to ``ncdump``), in
-    which case the the relevant constructs in memory will be created
+    which case the relevant constructs in memory will be created
     with data containing missing values.
 
     **PP and UM fields files**
@@ -377,21 +377,21 @@ def read(files, external=None, verbose=False, warnings=False,
     
     **Examples:**
     
-    >>> x = cfdm.read('file.nc')
+    >>> x = cf.read('file.nc')
     
     Read a file and create field constructs from CF-netCDF data
     variables as well as from the netCDF variables that correspond to
     particular types metadata constructs:
     
-    >>> f = cfdm.read('file.nc', extra='domain_ancillary')
-    >>> g = cfdm.read('file.nc', extra=['dimension_coordinate', 
-    ...                                 'auxiliary_coordinate'])
+    >>> f = cf.read('file.nc', extra='domain_ancillary')
+    >>> g = cf.read('file.nc', extra=['dimension_coordinate', 
+    ...                               'auxiliary_coordinate'])
     
     Read a file that contains external variables:
     
-    >>> h = cfdm.read('parent.nc')
-    >>> i = cfdm.read('parent.nc', external='external.nc')
-    >>> j = cfdm.read('parent.nc', external=['external1.nc', 'external2.nc'])
+    >>> h = cf.read('parent.nc')
+    >>> i = cf.read('parent.nc', external='external.nc')
+    >>> j = cf.read('parent.nc', external=['external1.nc', 'external2.nc'])
     
     >>> f = cf.read('file*.nc')
     >>> f
@@ -558,15 +558,15 @@ def read(files, external=None, verbose=False, warnings=False,
     if len(field_list) > 1:
         field_list.sort(key=lambda f: f.nc_get_variable(''))
         
-#    # ----------------------------------------------------------------
-#    # Add standard names to UM fields
-#    # ----------------------------------------------------------------
-#    for f in field_list:
-#        standard_name = getattr(f, '_standard_name', None)
-#        if standard_name is not None:
-#            f.standard_name = standard_name
-#            del f._standard_name
-#    #--- End: for
+    # ----------------------------------------------------------------
+    # Add standard names to UM/PP fields (post aggregation)
+    # ----------------------------------------------------------------
+    for f in field_list:
+        standard_name = f._custom.get('standard_name', None)
+        if standard_name is not None:
+            f.set_property('standard_name', standard_name)
+            del f._custom['standard_name']
+    #--- End: for
 
     # ----------------------------------------------------------------
     # Squeeze size one dimensions from the data arrays. Do one of:
@@ -711,7 +711,7 @@ def _read_a_file(filename, aggregate=True, aggregate_options=None,
         
     elif ftype == 'UM' and extra_read_vars['fmt'] in (None, 'UM'):
         fields = UM.read(filename, um_version=umversion,
-                         verbose=verbose, set_standard_name=True,
+                         verbose=verbose, set_standard_name=False,
                          height_at_top_of_model=height_at_top_of_model,
                          fmt=fmt, word_size=word_size, endian=endian,
                          chunk=chunk)
