@@ -5,16 +5,26 @@ import unittest
 import cf
 
 # Build the test suite from the tests found in the test files.
-testsuite_setup = unittest.TestSuite()
-testsuite_setup.addTests(unittest.TestLoader().discover('.', pattern='setup_create_field.py'))
+testsuite_setup_0 = unittest.TestSuite()
+testsuite_setup_0.addTests(unittest.TestLoader().discover('.', pattern='create_test_files.py'))
+
+# Build the test suite from the tests found in the test files.
+testsuite_setup_1 = unittest.TestSuite()
+testsuite_setup_1.addTests(unittest.TestLoader().discover('.', pattern='setup_create_field.py'))
 
 testsuite = unittest.TestSuite()
 testsuite.addTests(unittest.TestLoader().discover('.', pattern='test_*.py'))
 
 # Run the test suite.
-def run_test_suite_setup(verbosity=2):
+def run_test_suite_setup_0(verbosity=2):
     runner = unittest.TextTestRunner(verbosity=verbosity)
-    runner.run(testsuite_setup)
+    runner.run(testsuite_setup_0)
+
+    
+# Run the test suite.
+def run_test_suite_setup_1(verbosity=2):
+    runner = unittest.TextTestRunner(verbosity=verbosity)
+    runner.run(testsuite_setup_1)
 
     
 # Run the test suite.
@@ -35,7 +45,8 @@ if __name__ == '__main__':
 
     cf.CHUNKSIZE(original_chunksize)
 
-    run_test_suite_setup()
+    run_test_suite_setup_0()
+    run_test_suite_setup_1()
     run_test_suite()
 
     cf.CHUNKSIZE(original_chunksize)
