@@ -82,9 +82,8 @@ class DataTest(unittest.TestCase):
 #                          'test_Data_datetime_array',
 ##                          'test_Data_cumsum',
 #                          'test_Data_dumpd_loadd_dumps',
-##                          'test_Data_sin_cos_tan',
-##                          'test_Data_root_mean_square',
-##                          'test_Data_mean_mean_absolute_value',
+#                          'test_Data_root_mean_square',
+#                          'test_Data_mean_mean_absolute_value',
 #                          'test_Data_squeeze_insert_dimension',
 #                          'test_Data_months_years',
 #                          'test_Data_binary_mask',
@@ -603,7 +602,7 @@ class DataTest(unittest.TestCase):
                     self.assertTrue((d.array == a).all() in (True, numpy.ma.masked), message)
                     self.assertTrue((d.mask.array == numpy.ma.getmaskarray(a)).all(), message)
                 #--- End: for
-#                print 'hardmask =',hardmask,', pmshape =', d._pmshape
+#                print('hardmask =',hardmask,', pmshape =', d._pmshape)
             #--- End: for
 
         cf.CHUNKSIZE(self.original_chunksize)
@@ -1095,7 +1094,7 @@ class DataTest(unittest.TestCase):
                 self.assertTrue(d.min(_preserve_partitions=pp) == 2)
                 self.assertTrue(d.min(_preserve_partitions=pp).datum() == 2)
                 self.assertTrue(d.min(_preserve_partitions=pp) == cf.Data(0.002, 'km'))
-#            print 'pmshape =', d._pmshape
+#            print('pmshape =', d._pmshape)
 
         cf.CHUNKSIZE(self.original_chunksize)
 
@@ -2142,7 +2141,7 @@ class DataTest(unittest.TestCase):
                 b = reshape_array(self.a, axes) ** 2
                 v = reshape_array(self.w, axes)
                 b = numpy.average(b, axis=-1, weights=v) ** 0.5
-                
+
                 e = d.root_mean_square(axes=axes, weights=x, squeeze=True)
 
                 self.assertTrue(
@@ -2446,11 +2445,12 @@ class DataTest(unittest.TestCase):
             _ = d.exp()        
 
     
-    def test_Data_sin_cos_tan(self):
+    def test_Data_trigonometric_hyperbolic(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for method in ('sin', 'cos', 'tan'):                             
+        for method in ('sin', 'cos', 'tan', 'sinh', 'cosh', 'tanh',
+                       'arctan', 'arcsinh'):
             for x in (1, -1):
                 a = 0.9 * x * self.ma
                 c = getattr(numpy.ma, method)(a)                
@@ -2462,12 +2462,19 @@ class DataTest(unittest.TestCase):
                         self.assertTrue(getattr(d, method)(inplace=True) is None)
                         self.assertTrue(d.equals(e, verbose=True), "{}".format(method, ))   
                         self.assertTrue(d.shape == c.shape)
-                        self.assertTrue((d.array == c).all(), "{}, {}, {}".format(method, units, d.array-c))
+                        self.assertTrue(
+                            (d.array == c).all(),
+                             "{}, {}, {}".format(method, units, d.array-c)
+                        )
+                        self.assertTrue(
+                            (d.mask.array == c.mask).all(),
+                             "{}, {}, {}".format(method, units, d.array-c)
+                        )
         #--- End: for
         
         cf.CHUNKSIZE(self.original_chunksize)
-
         
+
 #--- End: class
 
 
