@@ -263,16 +263,28 @@ class FieldTest(unittest.TestCase):
         x = f.weights(w)
         self.assertTrue(x.equals(w, verbose=True))
 
+        self.assertTrue(isinstance(f.weights(), cf.Field))
+        self.assertTrue(isinstance(f.weights(True), cf.Field))
+        self.assertTrue(isinstance(f.weights(data=True), cf.Data))
+        self.assertTrue(isinstance(f.weights(components=True), dict))
+
         for components in (False, True):
             for m in (False, True):
-                y = f.weights(w.data.transpose(), components=components, measure=m)
-                y = f.weights(w.data.transpose()[0].squeeze(), components=components, measure=m)
-                y = f.weights(w.data.transpose()[0], components=components, measure=m)
-                y = f.weights(f.data.squeeze(), components=components, measure=m)
-                y = f.weights('auto', components=components, measure=m)
-                y = f.weights('grid_longitude', components=components, measure=m)
-                y = f.weights(['grid_longitude'], components=components, measure=m)
-    #--- End: for
+                for d in (False, True):
+                    if components:
+                        d = False
+
+                    y = f.weights(w, components=components, measure=m, data=d)
+                    y = f.weights(w.transpose(), components=components, measure=m, data=d)
+                    y = f.weights(w.data, components=components, measure=m, data=d)
+                    y = f.weights(f.data.squeeze(), components=components, measure=m, data=d)
+                    y = f.weights(components=components, measure=m, data=d)
+                    y = f.weights('grid_longitude', components=components, measure=m, data=d)
+                    y = f.weights(['grid_longitude'], components=components, measure=m, data=d)
+        #--- End: for
+
+        with self.assertRaises(Exception):
+            f.weights(components=True, data=True)
             
 
     def test_Field_replace_construct(self):
@@ -1511,30 +1523,29 @@ class FieldTest(unittest.TestCase):
         self.assertFalse(g.match_by_naxes(3))
         self.assertFalse(g.match_by_naxes(99, 88))
 
-        # match_by_construct
-        for mode in ([], ['and']):        
-            for constructs in ({},
-                               {'grid_longitude': None},
-                               {'grid_longitude': 20.0},
-                               {'grid_latitude': 9.0, 'Z': 1.5},
-                               {'grid_longitude': cf.wi(21, 30)},
-            ):
-                self.assertTrue(f.match_by_construct(*mode, **constructs),
-                                'Failed with mode={}, constructs={}'.format(
-                                    mode, constructs))
-
-        self.assertTrue(f.match_by_construct('or', Y=8888, Z=1.5))
-        self.assertFalse(f.match_by_construct(Y=8888, Z=1.5))
-        self.assertFalse(f.match_by_construct(T=89))
-        self.assertFalse(f.match_by_construct('or', T=None, qwerty=None))
-        self.assertFalse(f.match_by_construct('and', T=None, qwerty=None))
-        self.assertTrue(f.match_by_construct('or', T=None, grid_latitude=None))
-
-        with self.assertRaises(ValueError):
-            f.match_by_construct('qwerty', T=None, X=None)
-        with self.assertRaises(ValueError):
-            f.match_by_construct('or', 'and', X=None)
+        # Match by construct
+        for OR in (True, False):
+            self.assertTrue(f.match_by_construct(OR=OR))
+            self.assertTrue(f.match_by_construct('X', OR=OR))
+            self.assertTrue(f.match_by_construct('latitude', OR=OR))
+            self.assertTrue(f.match_by_construct('X', 'latitude', OR=OR))
+            self.assertTrue(f.match_by_construct('X', 'Y', OR=OR))
+            self.assertTrue(f.match_by_construct('X', 'Y', 'latitude', OR=OR))
+            self.assertTrue(f.match_by_construct('grid_latitude: max', OR=OR))
+            self.assertTrue(f.match_by_construct('grid_longitude: mean grid_latitude: max', OR=OR))
+            self.assertTrue(f.match_by_construct('X', 'method:max', OR=OR))
+            self.assertTrue(f.match_by_construct('X', 'grid_latitude: max', OR=OR))
+        
+            
+        self.assertFalse(f.match_by_construct('qwerty'))
+        self.assertFalse(f.match_by_construct('qwerty', OR=True))
+        self.assertFalse(f.match_by_construct('X', 'qwerty'))
+        self.assertFalse(f.match_by_construct('time: mean'))
 
+        self.assertTrue(f.match_by_construct('X', 'qwerty', OR=True))
+        self.assertTrue(f.match_by_construct('X', 'qwerty', 'method:max', 'over:years', OR=True))
+        self.assertTrue(f.match_by_construct('X', 'qwerty', 'grid_latitude: max', 'over:years', OR=True))
+        
 
     def test_Field_period(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
