@@ -5,101 +5,104 @@ import tempfile
 import time 
 import unittest
 
-import netCDF4
 import numpy
 
 import cf
 
-def _make_files():
-    '''
-    '''
-    def _pp(filename, parent=False, external=False, combined=False, external_missing=False):
-        '''
-        '''
-        nc = netCDF4.Dataset(filename, 'w', format='NETCDF3_CLASSIC')
-        
-        nc.createDimension('grid_latitude', 10)
-        nc.createDimension('grid_longitude', 9)
-        
-        nc.Conventions = 'CF-1.7'
-        if parent:
-            nc.external_variables = 'areacella'
-
-        if parent or combined or external_missing:
-            grid_latitude = nc.createVariable(dimensions=('grid_latitude',),
-                                              datatype='f8',
-                                              varname='grid_latitude')
-            grid_latitude.setncatts({'units': 'degrees', 'standard_name': 'grid_latitude'})
-            grid_latitude[...] = range(10)
-            
-            grid_longitude = nc.createVariable(dimensions=('grid_longitude',),
-                                               datatype='f8',
-                                               varname='grid_longitude')
-            grid_longitude.setncatts({'units': 'degrees', 'standard_name': 'grid_longitude'})
-            grid_longitude[...] = range(9)
-            
-            latitude = nc.createVariable(dimensions=('grid_latitude', 'grid_longitude'),
-                                         datatype='i4',
-                                         varname='latitude')
-            latitude.setncatts({'units': 'degree_N', 'standard_name': 'latitude'})
-            
-            latitude[...] = numpy.arange(90).reshape(10, 9)
-            
-            longitude = nc.createVariable(dimensions=('grid_longitude', 'grid_latitude'),
-                                          datatype='i4',
-                                          varname='longitude')
-            longitude.setncatts({'units': 'degreeE', 'standard_name': 'longitude'})
-            longitude[...] = numpy.arange(90).reshape(9, 10)
-            
-            eastward_wind = nc.createVariable(dimensions=('grid_latitude', 'grid_longitude'),
-                                              datatype='f8',
-                                              varname=u'eastward_wind')
-            eastward_wind.coordinates = u'latitude longitude'
-            eastward_wind.standard_name = 'eastward_wind'
-            eastward_wind.cell_methods = 'grid_longitude: mean (interval: 1 day comment: ok) grid_latitude: maximum where sea'
-            eastward_wind.cell_measures = 'area: areacella'
-            eastward_wind.units = 'm s-1'
-            eastward_wind[...] = numpy.arange(90).reshape(10, 9) - 45.5
-
-        if external or combined:                
-            areacella = nc.createVariable(dimensions=('grid_longitude', 'grid_latitude'),
-                                          datatype='f8',
-                                          varname='areacella')
-            areacella.setncatts({'units': 'm2', 'standard_name': 'cell_area'})
-            areacella[...] = numpy.arange(90).reshape(9, 10) + 100000.5
-            
-        nc.close()
-    #--- End: def
-
-    parent_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                               'parent.nc')        
-    external_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 'external.nc')            
-    combined_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                 'combined.nc')        
-    external_missing_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                                         'external_missing.nc')            
-    
-    _pp(parent_file          , parent=True)
-    _pp(external_file        , external=True)
-    _pp(combined_file        , combined=True)
-    _pp(external_missing_file, external_missing=True)
-
-    return parent_file, external_file, combined_file, external_missing_file
-
-
-(parent_file,
- external_file,
- combined_file,
- external_missing_file) = _make_files()
+#def _make_files():
+#    '''
+#    '''
+#    def _pp(filename, parent=False, external=False, combined=False, external_missing=False):
+#        '''
+#        '''
+#        nc = netCDF4.Dataset(filename, 'w', format='NETCDF3_CLASSIC')
+#        
+#        nc.createDimension('grid_latitude', 10)
+#        nc.createDimension('grid_longitude', 9)
+#        
+#        nc.Conventions = 'CF-1.7'
+#        if parent:
+#            nc.external_variables = 'areacella'
+#
+#        if parent or combined or external_missing:
+#            grid_latitude = nc.createVariable(dimensions=('grid_latitude',),
+#                                              datatype='f8',
+#                                              varname='grid_latitude')
+#            grid_latitude.setncatts({'units': 'degrees', 'standard_name': 'grid_latitude'})
+#            grid_latitude[...] = range(10)
+#            
+#            grid_longitude = nc.createVariable(dimensions=('grid_longitude',),
+#                                               datatype='f8',
+#                                               varname='grid_longitude')
+#            grid_longitude.setncatts({'units': 'degrees', 'standard_name': 'grid_longitude'})
+#            grid_longitude[...] = range(9)
+#            
+#            latitude = nc.createVariable(dimensions=('grid_latitude', 'grid_longitude'),
+#                                         datatype='i4',
+#                                         varname='latitude')
+#            latitude.setncatts({'units': 'degree_N', 'standard_name': 'latitude'})
+#            
+#            latitude[...] = numpy.arange(90).reshape(10, 9)
+#            
+#            longitude = nc.createVariable(dimensions=('grid_longitude', 'grid_latitude'),
+#                                          datatype='i4',
+#                                          varname='longitude')
+#            longitude.setncatts({'units': 'degreeE', 'standard_name': 'longitude'})
+#            longitude[...] = numpy.arange(90).reshape(9, 10)
+#            
+#            eastward_wind = nc.createVariable(dimensions=('grid_latitude', 'grid_longitude'),
+#                                              datatype='f8',
+#                                              varname=u'eastward_wind')
+#            eastward_wind.coordinates = u'latitude longitude'
+#            eastward_wind.standard_name = 'eastward_wind'
+#            eastward_wind.cell_methods = 'grid_longitude: mean (interval: 1 day comment: ok) grid_latitude: maximum where sea'
+#            eastward_wind.cell_measures = 'area: areacella'
+#            eastward_wind.units = 'm s-1'
+#            eastward_wind[...] = numpy.arange(90).reshape(10, 9) - 45.5
+#
+#        if external or combined:                
+#            areacella = nc.createVariable(dimensions=('grid_longitude', 'grid_latitude'),
+#                                          datatype='f8',
+#                                          varname='areacella')
+#            areacella.setncatts({'units': 'm2', 'standard_name': 'cell_area'})
+#            areacella[...] = numpy.arange(90).reshape(9, 10) + 100000.5
+#            
+#        nc.close()
+#    #--- End: def
+#
+#    parent_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+#                               'parent.nc')        
+#    external_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+#                                 'external.nc')            
+#    combined_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+#                                 'combined.nc')        
+#    external_missing_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+#                                         'external_missing.nc')            
+#    
+#    _pp(parent_file          , parent=True)
+#    _pp(external_file        , external=True)
+#    _pp(combined_file        , combined=True)
+#    _pp(external_missing_file, external_missing=True)
+#
+#    return parent_file, external_file, combined_file, external_missing_file
+#
+#
+#(parent_file,
+# external_file,
+# combined_file,
+# external_missing_file) = _make_files()
 
 
 class ExternalVariableTest(unittest.TestCase):
     def setUp(self):
-        self.parent_file           = parent_file
-        self.external_file         = external_file
-        self.combined_file         = combined_file
-        self.external_missing_file = external_missing_file
+        self.parent_file           = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                                  'parent.nc')
+        self.external_file         = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                                  'external.nc')
+        self.combined_file         = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                                  'combined.nc')
+        self.external_missing_file = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                                  'external_missing.nc')
         
         self.test_only = []
 
