@@ -6,10 +6,9 @@ class Units:
     values to different units.
     
     This is a convenience class that creates a `cfunits.Units`
-    instance (https://ncas-cms.github.io/cfunits). For further
-    details, type
-    
-       >>> help(cf.Units())
+    instance.
+
+    The full documentation is available with ``help(cf.Units())``.
 
     '''
     def __new__(cls, *args, **kwargs):
